Re: [PATCH] fetch-pack: speed up loading of refs via commit graph
- From
Jeff King <peff@peff.net>
- Date
- Aug 5, 2021, 20:42 UTC
- Message-ID
- <YQxNQJNGOZW6CR6L@coredump.intra.peff.net>
- In-Reply-To
- <YQvRTpJ0NGakTy9W@ncase>
On Thu, Aug 05, 2021 at 01:53:50PM +0200, Patrick Steinhardt wrote:
Show 8 quoted lines
> I've put some more time into this. If rebased on top of v4 of [1], then > we can also use `parse_commit_in_graph_gently()` to further speed this > up from 15.8 seconds to 11.6 seconds with below patch. It's the same > memory/speed tradeoff as I'm doing in [1]. > > I guess I'd still like to treat both series separately for now given > that [1] is more involved compared to this patch series here. I'll then > do a follow-up when (if?) both series have landed.
Heh, I should have read this before writing my other response. Your strategy here is what I imagined. If you split the find/fill steps from parse_commit_in_graph(), then you should be able to speculatively ask "if this is a commit in the graph, fill it in, otherwise do nothing". Which would solve the memory tradeoff.
-Peff